# Class: safeshare::access_service_migration
#
#   Setup the tool which is used to maintain the Access Service' database
#   schema.
#   The tool has access to more database privileges which are not required by
#   the Access Service itself and therefore it is beneficial for the tool to
#   be installed on a separate server from the Access Service.
#
# Parameters:
#
#  [*version*]
#    Optional. Default value is `latest`.
#    The SafeShare Access Service Migration version to install.
#    Should be version 3.0 and above. Should include the full
#    version number (e.g. '3.0-965-1'). Can also be any possible
#    `Package` resource `ensure` value such as `latest` or `present`
#
#  [*webapp_service_url*]
#    URL of the Web app
#
#  [*access_service_url*]
#    URL of the Access Service.
#
#  [*database_password*]
#    The password of the database user used by the migration tool.
#    The database username is `so3`, it can't be changed via this module.
#
#  [*database_hostname*]
#    Optional. Default value is `localhost`.
#    The hostname of the database used by the migration tool if
#    required to connect to an external database instance.
#
# Actions:
#
# Requires:
#
# Sample Usage:
#
class safeshare::access_service_migration(
  $version            = $safeshare::access_service_migration::params::version,
  $access_service_url = $safeshare::access_service_migration::params::access_service_url,
  $webapp_service_url = $safeshare::access_service_migration::params::webapp_service_url,
  $database_password  = $safeshare::access_service_migration::params::database_password,
  $database_hostname  = $safeshare::access_service_migration::params::database_hostname,
) inherits safeshare::access_service_migration::params
{
  if $webapp_service_url == undef {
    fail('webapp_service_url needs to be defined')
  }

  if $database_password == undef {
    fail('database_password needs to be defined')
  }

  if $access_service_url == undef {
    fail('access_service_url needs to be defined')
  }

  anchor { 'safeshare::access_service_migration::begin': }
  ->
  class { 'safeshare::access_service_migration::install':}
  ->
  class { 'safeshare::access_service_migration::config': }
  ->
  class { 'safeshare::access_service_migration::migration': }
  ->
  anchor { 'safeshare::access_service_migration::end': }
}
